function [iotaout,rhoout,Vout,prof,ms,prices,prodsur,conssur,expfreq, ...
    tildes, cond_num] = fpstrat(constants,transition,profpar, ...
    control,lambda,iota1,rho1,xmax,ignore)
% INPUTS:   - constants,transition,profpar, and control parameters
%           - entry rate lambda 
%           - initial investment strategy iota1 (xmax x 1)
%           - initial exit strategy rho1 (xmax x 1)
%           - initial value xmax 
%           - variable ignore: ignore=1 if the presence of "my" firm is 
%             ignored when computing profits. In this way only 
%             need to compute profits once 
% OUTPUTS:  - investment strategy iotaout and exit strategy rhoout (xmax x 1)
%             which is fixed point given entry rate lambda
%           - value function Vout associated to fixed point (xmax x 1)
%           - profits assocciated to fixed point:
%             prof,ms,prices,prodsur,conssur (xmax x 1)
%           - expfreq (xmax x 1): if entry and exit, expected number of visits
%             to each state by one firm under fixed point strats.
%             if no entry/no exit, invariant distr.
%             of Markov chain that describes evolution of one firm    
%           - tildes: expected state under fixed point strats. (xmax x 1)
%           - cond_num: condition number matrix inversion for expfreq


% Rename parameters to be used in this function
% to simplify notation
TOL_probs=control.TOL_probs;
NMAX_strats=control.NMAX_strats;
expupdatestrat=control.expupdatestrat;

n=1;

tranmat1 = tranprob(transition,iota1,xmax);
[prcont1,condexp1] = contprob(transition,rho1);
prcont0=prcont1+TOL_probs*100;
tranmat0=tranmat1+TOL_probs*100;
iota0=0;
rho0=0;

while((max(abs(prcont1-prcont0))>TOL_probs | max(max(abs(tranmat1-tranmat0)))>TOL_probs) ...
      & n<=NMAX_strats)
  % smooth update of strategies
  iota0=iota1/(n^(expupdatestrat))+iota0*(1-1/(n^(expupdatestrat)));
  rho0=rho1/(n^(expupdatestrat))+rho0*(1-1/(n^(expupdatestrat)));
   
  [prcont0,condexp0] = contprob(transition,rho0);
  tranmat0 = tranprob(transition,iota0,xmax);
  conttranmat0 = conttranprob(prcont0,tranmat0,xmax);
   
  [expfreq, tildes, cond_num] = expstate(constants,control,conttranmat0,lambda,xmax);
   
  [prof,ms,prices,prodsur,conssur] = comp_prof(profpar,tildes,xmax,ignore);
   
  [iota1,rho1,V1,tranmat1,prcont1] = valueit(constants,transition,control,prof,xmax);
  
  n=n+1;
end
iotaout=iota1;
rhoout=rho1;
Vout=V1;









