function iota = optinv(constants,transition,Vold,xmax)
% INPUTS:   - constants, transition parameters
%           - value function Vold (xmax x 1)
%           - xmax
% OUTPUTS:  - optimal strategies iota, given Vold (xmax x 1)
%
% Assumes transition dynamics in Weintraub, Benkard, and Van Roy (2005)
% to compute optimal investment

% Rename parameters to be used in this function
% to simplify notation
beta=constants.beta;
d=constants.d;
a=transition.a;
delta=transition.delta;

i=2:xmax-1;
difV=zeros(xmax,1);
difV(2:xmax-1)=Vold(i+1)*(1-delta)+Vold(i)*(2*delta-1)+Vold(i-1)*(-delta);
difV(1)=Vold(2)*(1-delta)+Vold(1)*(delta-1);
difV(xmax)=Vold(xmax)*delta+Vold(xmax-1)*(-delta);
difV=(difV>0).*difV + (difV<=0).*0;  
iota=(difV>0).*(1/a*sqrt(a*beta*difV/d)-1/a) + (difV<=0).*0;
iota=(iota>0).*iota + (iota<=0).*0;