function [tranmat] = tranprob(transition,iota,xmax)

% INPUTS:   - transition parameters 
%           - investment strategy iota (xmax x 1) 
%           - xmax
% OUPUTS:   - matrix of transition probabilities tranmat (xmax x xmax)
%           
% Assumes transition dynamics in Weintraub, Benkard, and Van Roy (2005)


% Rename parameters to be used in this function
% to simplify notation
a=transition.a;
delta=transition.delta;

prup=(1-delta)*a*iota./(1+a*iota);           % prob. going up one state
prsame=(delta*a*iota+(1-delta))./(1+a*iota); % prob. stay in same state 
prdown=delta./(1+a*iota);                    % prob. go down one state

prsame(xmax)=1-prdown(xmax);        % At state xmax can't go up
prsame(1)=1-prup(1);                % At state 1 can't go down
  
% Using probs. to build matrix of transition probs.
prup=[0;prup(1:xmax-1)];
prdown=[prdown(2:xmax);0];
Prtrans=zeros(xmax);
tranmat=spdiags([prdown,prsame,prup],-1:1,Prtrans); 

