function [iota,rho,Vnew,tranmat,prcont] = valueit(constants,transition,control,prof,xmax)
%
% INPUTS:   - constants, transition, and control parameters
%           - profit function prof (xmax x 1)
%           - xmax
% OUTPUTS:  - optimal strategies iota, rho given profits prof (xmax x 1)
%           - optimal value function Vnew given profits prof  (xmax x 1)
%           - transition probs tranmat given iota (xmax x xmax)
%           - continuation probs prcont given rho (xmax x 1)
% Solves Bellman's equation using value iteration


% Rename parameters to be used in this function
% to simplify notation
beta=constants.beta;
d=constants.d;
K=transition.K;
TOL_valueit=control.TOL_valueit;

Vnew=(K+prof/(1-beta));
Vold=Vnew+TOL_valueit*100;

while(max(abs(Vnew-Vold))>TOL_valueit)  % value iteration to solve Bellman's equation
    Vold=Vnew;
    
    % Compute optimal investment
    iota = optinv(constants,transition,Vold,xmax);
    
    % Compute transition probabilities
    tranmat = tranprob(transition,iota,xmax);
    
    % Compute continuation values if not exiting
    rho = -d*iota + beta*(tranmat*Vold);

    % Compute continuation probs. and conditional expectation sell-off
    % value, conditional on exiting
    [prcont,condexp] = contprob(transition,rho);
    
    % Update value function
    Vnew = prof + (1-prcont).*(condexp)+(prcont).*rho;
end  % while value iteration



